Git-buildpackage
----------------
Tools to ease the development of Debian and (partially) RPM packages in git
repositories.  For documentation see the manual online at:

  http://honk.sigxcpu.org/projects/git-buildpackage/manual-html/gbp.html

On Debian systems, the documentation can be found in
/usr/share/doc/git-buildpackage/manual-html.

The API documentation of the gbp module can be found at:

  http://honk.sigxcpu.org/projects/git-buildpackage/apidocs

The mailing list is at:

  * http://lists.sigxcpu.org/mailman/listinfo/git-buildpackage
  * git-buildpackage at lists.sigxcpu.org

See the HACKING document for details on contributing to gbp development. The
package is also available on Pypi at:

  https://pypi.python.org/pypi/gbp/

[![Build Status](https://travis-ci.org/agx/git-buildpackage.svg?branch=master)](https://travis-ci.org/agx/git-buildpackage)
